<?php

namespace App\Http\Controllers;

use App\Models\Stock;
use Exception;
use App\Imports\StockImport;
use Illuminate\Http\Request;
use Maatwebsite\Excel\Facades\Excel;

class StockController extends Controller
{
    public function stocks()
    {
        $stocks = Stock::all();
        return view('admin.stock.index', ['stocks' => $stocks]);
    }

    public function add_stock(Request $request)
    {
        try {
            $stock = new Stock();
            $stock->length = $request->length;
            $stock->cost = $request->cost;
            $stock->save();
            return redirect()->back()->with('success', 'Stock added successfully');
        } catch (Exception $e) {
            return redirect()->back()->with('error', $e->getMessage());
        }
    }

    public function update_stock(Request $request)
    {
        try {
            $stock = Stock::where('id', $request->id)->first();
            $stock->length = $request->edit_length;
            $stock->cost = $request->edit_cost;
            $stock->save();
            return redirect()->back()->with('success', 'Stock updated successfully');
        } catch (Exception $e) {
            return redirect()->back()->with('error', $e->getMessage());
        }
    }
    public function delete_stock($id)
    {
        try {
            $stock = Stock::where('id', $id)->first();
            $stock->delete();
            return redirect()->back()->with('success', 'Stock deleted successfully');
        } catch (Exception $e) {
            return redirect()->back()->with('error', $e->getMessage());
        }
    }
    public function import_stock(Request $request)
    {
        // Validate the uploaded file
        $request->validate([
            'stock_file' => 'required|file|mimes:xlsx,xls,csv',
        ]);

        try {
            // Process the file and import stocks
            Excel::import(new StockImport, $request->file('stock_file'));

            return redirect()->back()->with('success', 'Stocks imported successfully!');
        } catch (\Exception $e) {
            return redirect()->back()->with('error', 'Error importing stocks: ' . $e->getMessage());
        }
    }


}
